@@ -4,6 +4,8 @@ import os
 from selenium.webdriver.common.keys import Keys
 from auto_upload.utils.uploader.upload_tools import *
 from selenium.webdriver.support.select import Select
+import re
+from selenium.webdriver.common.by import By
 
 def hdpt_upload(web,file1,record_path,qbinfo):
 
@@ -20,20 +22,20 @@ def hdpt_upload(web,file1,record_path,qbinfo):
 
     logger.info('正在'+web.site.sitename+'发布种子...')
     try:
-        web.driver.find_element_by_class_name('file').send_keys(file1.torrentpath);
+        web.driver.find_element(By.CLASS_NAME,'file').send_keys(file1.torrentpath);
     except Exception as r:
         logger.warning('上传种子文件发生错误，错误信息: %s' %(r))
         return False,fileinfo+'上传种子文件发生错误'
     logger.info('已成功上传种子')
 
     try:
-        if len(web.driver.find_elements_by_name('name'))<=0:
+        if len(web.driver.find_elements(By.NAME,'name'))<=0:
             web.driver.execute_script("window.scrollBy(0,300)")
-        #web.driver.find_elements_by_name('name')[0].click()
-        web.driver.find_elements_by_name('name')[0].send_keys(Keys.CONTROL, "a")
-        web.driver.find_elements_by_name('name')[0].send_keys(Keys.BACKSPACE)
-        web.driver.find_elements_by_name('name')[0].send_keys(Keys.BACKSPACE)
-        web.driver.find_elements_by_name('name')[0].send_keys(file1.uploadname)
+        #web.driver.find_elements(By.NAME,'name')[0].click()
+        web.driver.find_elements(By.NAME,'name')[0].send_keys(Keys.CONTROL, "a")
+        web.driver.find_elements(By.NAME,'name')[0].send_keys(Keys.BACKSPACE)
+        web.driver.find_elements(By.NAME,'name')[0].send_keys(Keys.BACKSPACE)
+        web.driver.find_elements(By.NAME,'name')[0].send_keys(file1.uploadname)
         logger.info('已成功填写主标题')
     except Exception as r:
         logger.warning('填写主标题发生错误，错误信息: %s' %(r))
@@ -41,8 +43,8 @@ def hdpt_upload(web,file1,record_path,qbinfo):
     logger.info('已成功填写主标题')
 
     try:
-        #web.driver.find_elements_by_name('small_descr')[0].click()
-        web.driver.find_elements_by_name('small_descr')[0].send_keys(file1.small_descr)
+        #web.driver.find_elements(By.NAME,'small_descr')[0].click()
+        web.driver.find_elements(By.NAME,'small_descr')[0].send_keys(file1.small_descr+file1.pathinfo.exinfo)
         logger.info('已成功填写副标题')
     except Exception as r:
         logger.warning('填写副标题发生错误，错误信息: %s' %(r))
@@ -51,8 +53,8 @@ def hdpt_upload(web,file1,record_path,qbinfo):
 
     logger.info('正在填写简介,请稍等...')
     try:
-        #web.driver.find_elements_by_name('descr')[0].click()
-        web.driver.find_elements_by_name('descr')[0].send_keys(file1.content)
+        #web.driver.find_elements(By.NAME,'descr')[0].click()
+        web.driver.find_elements(By.NAME,'descr')[0].send_keys(file1.content)
         logger.info('已成功填写简介')
     except Exception as r:
         logger.warning('填写简介发生错误，错误信息: %s' %(r))
@@ -64,7 +66,7 @@ def hdpt_upload(web,file1,record_path,qbinfo):
         select_type = Select(select_type)
         if 'anime' in file1.pathinfo.type.lower():
             select_type.select_by_value('405')
-            checkbox=web.driver.find_elements_by_name('tags[]')
+            checkbox=web.driver.find_elements(By.NAME,'tags[]')
             if len(checkbox)>0:
                 checkbox=checkbox[7]
                 if not checkbox.is_selected():
@@ -86,7 +88,7 @@ def hdpt_upload(web,file1,record_path,qbinfo):
             select_type.select_by_value('409')
         elif 'cartoon' in file1.pathinfo.type.lower():
             select_type.select_by_value('412')
-            checkbox=web.driver.find_elements_by_name('tags[]')
+            checkbox=web.driver.find_elements(By.NAME,'tags[]')
             if len(checkbox)>0:
                 checkbox=checkbox[7]
                 if not checkbox.is_selected():
@@ -214,7 +216,7 @@ def hdpt_upload(web,file1,record_path,qbinfo):
             select_team_sel_ob.select_by_value('15')
         elif 'HARES' in file1.sub.upper():
             select_team_sel_ob.select_by_value('16')
-        elif 'GMD' in file1.sub.upper():
+        elif 'HDPT' in file1.sub.upper():
             select_team_sel_ob.select_by_value('18')
         else:
             select_team_sel_ob.select_by_value('17')
@@ -226,7 +228,7 @@ def hdpt_upload(web,file1,record_path,qbinfo):
 
     try:
         if not file1.sublan=='' and ('简' in file1.sublan or '繁' in file1.sublan or '中' in file1.sublan):
-            checkbox=web.driver.find_elements_by_name('tags[]')
+            checkbox=web.driver.find_elements(By.NAME,'tags[]')
             if len(checkbox)>0:
                 checkbox=checkbox[4]
                 if not checkbox.is_selected():
@@ -237,7 +239,7 @@ def hdpt_upload(web,file1,record_path,qbinfo):
 
     try:
         if 'hdpt' in file1.sub.lower():
-            checkbox=web.driver.find_elements_by_name('tags[]')
+            checkbox=web.driver.find_elements(By.NAME,'tags[]')
             if len(checkbox)>0:
                 checkbox=checkbox[0]
                 if not checkbox.is_selected():
@@ -249,7 +251,7 @@ def hdpt_upload(web,file1,record_path,qbinfo):
 
     try:
         if file1.pathinfo.transfer==0:
-            checkbox=web.driver.find_elements_by_name('tags[]')
+            checkbox=web.driver.find_elements(By.NAME,'tags[]')
             if len(checkbox)>0:
                 checkbox=checkbox[1]
                 if not checkbox.is_selected():
@@ -261,7 +263,7 @@ def hdpt_upload(web,file1,record_path,qbinfo):
 
     try:
         if '国' in file1.language or '中' in file1.language:
-            checkbox=web.driver.find_elements_by_name('tags[]')
+            checkbox=web.driver.find_elements(By.NAME,'tags[]')
             if len(checkbox)>0:
                 checkbox=checkbox[2]
                 if not checkbox.is_selected():
@@ -273,7 +275,7 @@ def hdpt_upload(web,file1,record_path,qbinfo):
 
     try:
         if 'hdpt' in file1.pathinfo.exclusive:
-            checkbox=web.driver.find_elements_by_name('tags[]')
+            checkbox=web.driver.find_elements(By.NAME,'tags[]')
             if len(checkbox)>0:
                 checkbox=checkbox[11]
                 if not checkbox.is_selected():
@@ -284,7 +286,7 @@ def hdpt_upload(web,file1,record_path,qbinfo):
 
     try:
         if web.site.uplver==1:
-            checkbox=web.driver.find_elements_by_name('uplver')
+            checkbox=web.driver.find_elements(By.NAME,'uplver')
             if len(checkbox)>0:
                 checkbox=checkbox[0]
                 if not checkbox.is_selected():
@@ -297,7 +299,7 @@ def hdpt_upload(web,file1,record_path,qbinfo):
     #a=input('check')
     String_url = web.driver.current_url;
     try:
-        web.driver.find_elements_by_id('qr')[0].click()
+        web.driver.find_elements(By.ID,'qr')[0].click()
     except Exception as r:
         logger.warning('发布种子发生错误，错误信息: %s' %(r))
         return False,fileinfo+'发布种子发生错误'
@@ -313,7 +315,7 @@ def hdpt_upload(web,file1,record_path,qbinfo):
     
     recordupload(os.path.join(record_path,web.site.sitename+'_torrent.csv'),file1,String_url,downloadurl)
     if not downloadurl =='':
-        res=qbseed(url=downloadurl,filepath=file1.path,qbinfo=qbinfo)
+        res=qbseed(url=downloadurl,filepath=file1.pathinfo.downloadpath,qbinfo=qbinfo)
         if res:
             return True,fileinfo+'种子发布成功,种子链接:'+downloadurl+',当前网址:'+web.driver.current_url
         else:
